/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2006-2010 Smithsonian Astrophysical Observatory
 *
 * This file is part of aperture
 *
 * aperture is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * -->8-->8-->8-->8-- */

#include <string.h>

#include <tracefct/tracefct.h>
#include <tracefct/exiterrvals.h>
#include <tparam/tparam.h>
#include <suplib/str.h>

#include "common.h"
#include "params.h"

#define LUA                "aperture"
#define INPUT              "input"
#define LOOPIT             "loop"
#define OUTPUT             "output"
#define OVERRIDE           "override"
#define STATISTICSFILENAME "statfname"

void
  get_parameters( int argc, char *argv[], Params *io )
{

  paramfile pf;

  tf_enter("get_parameters");

  pf = tparamopen( NULL, argv, argc, "r" );

  io->help = tpgetb( pf, "help" );
  io->version = tpgetb( pf, "version" );

  if ( ! io->help && ! io->version )
  {
      tpgetstr( pf, INPUT, io->in, PBUFSIZE, 1);

      tpgetstr( pf, OUTPUT, io->out, PBUFSIZE, 1);

      tpgetstr( pf, LUA, io->lua, PBUFSIZE, 1 );

      tpgetstr( pf, STATISTICSFILENAME, io->statistics, PBUFSIZE, 1 );

      if ( 0 == strcmp( io->in, io->out ) )
	  tf_exit( ExitERR_IOerr,
		   "The input filename must be different from the output filename" );

      tpgetstr( pf, OVERRIDE, io->override, PBUFSIZE, 0);
      str_prune( io->override );

      loop_it = tpgetb( pf, LOOPIT );
  }

  paramclose(pf);

  tf_leave();
}


